@@ -1,13 +1,19 @@
 # -*- coding: utf-8 -*-
 
-# ########################## Copyrights and license ############################
+############################ Copyrights and license ############################
 #                                                                              #
 # Copyright 2012 Vincent Jacques <vincent@vincent-jacques.net>                 #
 # Copyright 2012 Zearin <zearin@gonk.net>                                      #
 # Copyright 2013 Vincent Jacques <vincent@vincent-jacques.net>                 #
+# Copyright 2014 Vincent Jacques <vincent@vincent-jacques.net>                 #
+# Copyright 2016 Jannis Gebauer <ja.geb@me.com>                                #
+# Copyright 2016 Peter Buckley <dx-pbuckley@users.noreply.github.com>          #
+# Copyright 2017 Balázs Rostás <rostas.balazs@gmail.com>                     #
+# Copyright 2018 Anton Nguyen <afnguyen85@gmail.com>                           #
+# Copyright 2018 sfdye <tsfdye@gmail.com>                                      #
 #                                                                              #
 # This file is part of PyGithub.                                               #
-# http://pygithub.github.io/PyGithub/v1/index.html                             #
+# http://pygithub.readthedocs.io/                                              #
 #                                                                              #
 # PyGithub is free software: you can redistribute it and/or modify it under    #
 # the terms of the GNU Lesser General Public License as published by the Free  #
@@ -22,7 +28,7 @@
 # You should have received a copy of the GNU Lesser General Public License     #
 # along with PyGithub. If not, see <http://www.gnu.org/licenses/>.             #
 #                                                                              #
-# ##############################################################################
+################################################################################
 
 import Framework
 
@@ -35,35 +41,53 @@ class Organization(Framework.TestCase):
         self.org = self.g.get_organization("BeaverSoftware")
 
     def testAttributes(self):
-        self.assertEqual(self.org.avatar_url, "https://secure.gravatar.com/avatar/d563e337cac2fdc644e2aaaad1e23266?d=https://a248.e.akamai.net/assets.github.com%2Fimages%2Fgravatars%2Fgravatar-orgs.png")
-        self.assertEqual(self.org.billing_email, "BeaverSoftware@vincent-jacques.net")
-        self.assertEqual(self.org.blog, None)
-        self.assertEqual(self.org.collaborators, 0)
+        self.assertEqual(self.org.avatar_url, "https://avatars1.githubusercontent.com/u/1?v=4")
+        self.assertEqual(self.org.billing_email, "foo@example.com")
+        self.assertEqual(self.org.blog, "http://www.example.com")
+        self.assertEqual(self.org.collaborators, 9)
         self.assertEqual(self.org.company, None)
-        self.assertEqual(self.org.created_at, datetime.datetime(2012, 2, 9, 19, 20, 12))
-        self.assertEqual(self.org.disk_usage, 112)
-        self.assertEqual(self.org.email, None)
+        self.assertEqual(self.org.created_at, datetime.datetime(2014, 1, 9, 16, 56, 17))
+        self.assertEqual(self.org.disk_usage, 2)
+        self.assertEqual(self.org.email, '')
         self.assertEqual(self.org.followers, 0)
         self.assertEqual(self.org.following, 0)
         self.assertEqual(self.org.gravatar_id, None)
         self.assertEqual(self.org.html_url, "https://github.com/BeaverSoftware")
-        self.assertEqual(self.org.id, 1424031)
+        self.assertEqual(self.org.id, 1)
         self.assertEqual(self.org.location, "Paris, France")
         self.assertEqual(self.org.login, "BeaverSoftware")
-        self.assertEqual(self.org.name, None)
+        self.assertEqual(self.org.name, "BeaverSoftware")
         self.assertEqual(self.org.owned_private_repos, 0)
         self.assertEqual(self.org.plan.name, "free")
-        self.assertEqual(self.org.plan.private_repos, 0)
-        self.assertEqual(self.org.plan.space, 307200)
+        self.assertEqual(self.org.plan.private_repos, 3)
+        self.assertEqual(self.org.plan.space, 1)
         self.assertEqual(self.org.private_gists, 0)
         self.assertEqual(self.org.public_gists, 0)
-        self.assertEqual(self.org.public_repos, 2)
-        self.assertEqual(self.org.total_private_repos, 0)
+        self.assertEqual(self.org.public_repos, 27)
+        self.assertEqual(self.org.total_private_repos, 7)
         self.assertEqual(self.org.type, "Organization")
         self.assertEqual(self.org.url, "https://api.github.com/orgs/BeaverSoftware")
 
         # test __repr__() based on this attributes
-        self.assertEqual(self.org.__repr__(), 'Organization(name=None, id=1424031)')
+        self.assertEqual(self.org.__repr__(), 'Organization(name="BeaverSoftware", id=1)')
+
+    def testAddMembersDefaultRole(self):
+        lyloa = self.g.get_user("lyloa")
+        self.assertFalse(self.org.has_in_members(lyloa))
+        self.org.add_to_members(lyloa, role='member')
+        # 'Pending' members won't be in /orgs/:org/members/:user
+        self.assertFalse(self.org.has_in_members(lyloa))
+        self.org.remove_from_membership(lyloa)
+        self.assertFalse(self.org.has_in_members(lyloa))
+
+    def testAddMembersAdminRole(self):
+        lyloa = self.g.get_user("lyloa")
+        self.assertFalse(self.org.has_in_members(lyloa))
+        self.org.add_to_members(lyloa, role='admin')
+        # 'Pending' members won't be in /orgs/:org/members/:user
+        self.assertFalse(self.org.has_in_members(lyloa))
+        self.org.remove_from_membership(lyloa)
+        self.assertFalse(self.org.has_in_members(lyloa))
 
     def testEditWithoutArguments(self):
         self.org.edit()
@@ -77,15 +101,31 @@ class Organization(Framework.TestCase):
         self.assertEqual(self.org.location, "Location edited by PyGithub")
         self.assertEqual(self.org.name, "Name edited by PyGithub")
 
+    def testEditHookWithMinimalParameters(self):
+        hook = self.org.create_hook("web", {"url": "http://foobar.com"})
+        hook = self.org.edit_hook(hook.id, "mobile", {"url": "http://barfoo.com"})
+        self.assertEqual(hook.name, "mobile")
+
+    def testEditHookWithAllParameters(self):
+        hook = self.org.create_hook("web", {"url": "http://foobar.com"}, ["fork"], False)
+        hook = self.org.edit_hook(hook.id, "mobile", {"url": "http://barfoo.com"}, ["spoon"], True)
+        self.assertEqual(hook.name, "mobile")
+        self.assertEqual(hook.events, ["spoon"])
+        self.assertEqual(hook.active, True)
+
     def testCreateTeam(self):
         team = self.org.create_team("Team created by PyGithub")
         self.assertEqual(team.id, 189850)
 
     def testCreateTeamWithAllArguments(self):
         repo = self.org.get_repo("FatherBeaver")
-        team = self.org.create_team("Team also created by PyGithub", [repo], "push")
+        team = self.org.create_team("Team also created by PyGithub", [repo], "push", "secret")
         self.assertEqual(team.id, 189852)
 
+    def testDeleteHook(self):
+        hook = self.org.create_hook("web", {"url": "http://foobar.com"})
+        self.org.delete_hook(hook.id)
+
     def testPublicMembers(self):
         lyloa = self.g.get_user("Lyloa")
         self.assertFalse(self.org.has_in_public_members(lyloa))
@@ -97,6 +137,9 @@ class Organization(Framework.TestCase):
     def testGetPublicMembers(self):
         self.assertListKeyEqual(self.org.get_public_members(), lambda u: u.login, ["jacquev6"])
 
+    def testGetHooks(self):
+        self.assertListKeyEqual(self.org.get_hooks(), lambda h: h.id, [257993])
+
     def testGetIssues(self):
         self.assertListKeyEqual(self.org.get_issues(), lambda i: i.id, [])
 
@@ -126,6 +169,15 @@ class Organization(Framework.TestCase):
     def testGetTeams(self):
         self.assertListKeyEqual(self.org.get_teams(), lambda t: t.name, ["Members", "Owners"])
 
+    def testCreateHookWithMinimalParameters(self):
+        hook = self.org.create_hook("web", {"url": "http://foobar.com"})
+        self.assertEqual(hook.id, 257967)
+
+    def testCreateHookWithAllParameters(self):
+        hook = self.org.create_hook("web", {"url": "http://foobar.com"}, ["fork"], False)
+        self.assertTrue(hook.active)
+        self.assertEqual(hook.id, 257993)
+
     def testCreateRepoWithMinimalArguments(self):
         repo = self.org.create_repo(name="TestPyGithub")
         self.assertEqual(repo.url, "https://api.github.com/repos/BeaverSoftware/TestPyGithub")
